/**
 * @file mBluetooth.c
 * @author Simon Doppler
 * @version 1.1
 * @date 2019-04-16
 *
 * Voir le fichier mBluetooth.h pour la liste détaillée des changements.
 */

#include "mBluetooth.h"

#include "iDio.h"
#include "iUart.h"

#include "FreeRTOS.h"
#include "task.h"

#include <stdio.h>

#define BUFSIZE 128
static Int8 buffer[BUFSIZE];

void mBT_WriteChar(Int8 aData)
{
    while(!iUart_GetStatus(kUart1,kTransmitComplete));

    iUart_SetData(kUart1,aData);
}

void mBT_WriteString(Int8 *aDataPtr)
{
    while(*aDataPtr!=0)
    {
        mBT_WriteChar(*aDataPtr);

        aDataPtr++;
    }
}

bool mBT_ReadDataFromBuffer(Int8 *aBytePtr)
{
    bool aRet=false;

    aRet=iUart_IsBufferEmpty(kUart1);

    if(false==aRet)
    {
        *aBytePtr=iUart_GetCharFromBuffer(kUart1);
    }

    return aRet;
}

void mBT_readString(Int8 *buffer, UInt32 n) {
    int i;
    for (i = 0; i < n; ++i) {
        while (mBT_ReadDataFromBuffer(&(buffer[i])));
    }
}

void mBT_setup() {
    iUart_Config(kUart1);
    iUart_InitRxBuffer(kUart1,0);
    iDio_PinConfig(kPortC, kPin13, kAlternate1);
    iDio_SetPortDirection(kPortC, kMaskIo13, kIoOutput);
}

void mBT_open(Int8 *aModuleName, Int8* aModulePassword) {
    iDio_SetPort(kPortC, kMaskIo13, kIoOn);             // début de la connfiguration, PTC13 à 0 logique (3.3V)

    iUart_EnDisRx(kUart1,kEn);
    iUart_EnDisTx(kUart1,kEn);
    iUart_SetupBaudrate(kUart1, 38400);

    mBT_WriteString("AT+ORGL\r\n");                     // reset du module
    mBT_readString(buffer, 4);                          // TODO: vérifier si la réponse est OK\r\n

    sprintf(buffer, "AT+NAME=\"%s\"\r\n", aModuleName);
    mBT_WriteString(buffer);                            // Nom du bluetooth
    mBT_readString(buffer, 4);

    sprintf(buffer, "AT+PSWD=\"%s\"\r\n", aModulePassword);
    mBT_WriteString(buffer);                            // mot de passe
    mBT_readString(buffer, 4);

    mBT_WriteString("AT+ROLE=1\r\n");                   // mise en mode master
    mBT_readString(buffer, 4);

    iDio_SetPort(kPortC, kMaskIo13, kIoOff);            // fin de la configuration, PTC13 à 1 logique (0V)
}

void mBT_WriteConfig(Int8 *aDataPtr) {
    iDio_SetPort(kPortC, kMaskIo13, kIoOn);
    mBT_WriteString(aDataPtr);
    iDio_SetPort(kPortC, kMaskIo13, kIoOff);
}
