/**
 * @file mBluetooth.h
 * @author Simon Doppler
 * @version 1.1
 * @date 2019-04-16
 *
 * Gestion du module bluetooth
 *
 * La reconfiguration n'est pas supportée pour le moment,
 * il faut écrire les fonctions de configuration spécifiques.
 *
 * La gestion des versions est définie ainsi:
 *
 * La fonction prend le numéro de la version du fichier dans laquelle sa
 * version actuelle a été écrite pour la première fois. Chaque modification
 * de fonction donne lieu à une incrémentation de version décimale si la
 * fonctionnalité reste la même et de version entière si la fonctionnalité change
 * (par exemple, une fonction de la version 1.1 pourra être utilisée telle quelle
 * dans tous les versions 1.x, x>=1, mais pas dans les versions 2.y, etc...).
 *
 * | Version | Date       | Auteur     | Commentaires                            |
 * |:------- |:---------- |:---------- |:--------------------------------------- |
 * | 1.0     | 2019-04-09 | S. Doppler | Version initiale                        |
 * | 1.1     | 2019-04-16 | S. Doppler | Ajout de la fonction @see mBT_WriteChar |
 */

#ifndef __MBLUETOOTH__
#define __MBLUETOOTH__


#include "def.h"

/**
 * @brief Configuration du module BT
 *
 * @since 1.0
 * @version 1.0
 */
void mBT_setup();

/**
 * @brief Ouverture de la communication BT
 *
 * @param aModuleName Nom du module BT (visible de tous)
 * @param aModulePassword Mot de passe pour la connexion au module
 *
 * @since 1.0
 * @version 1.0
 */
void mBT_open(Int8 *aModuleName, Int8 *aModulePassword);

/**
 * @brief Écriture d'une chaine
 *
 * @param aDataPtr Chaine à écrire, doit se terminer par '\0'
 *
 * @since 1.0
 * @version 1.1
 *
 * Changements:
 *
 * * **dans la version 1.1**: utilisation de la fonction @see mBT_WriteChar
 */
void mBT_WriteString(Int8 *aDataPtr);

/**
 * @brief Écriture d'un byte
 *
 * @param aData Byte à écrire
 *
 * @since 1.1
 * @version 1.1
 */
void mBT_WriteChar(Int8 aData);

/**
 * @brief Écriture d'une chaine de configuration (commande AT)
 *
 * @param aDataPtr Chaine à écrire, doit se terminer par '\r\n\0' et commencer par 'AT'
 *
 * @since 1.0
 * @version 1.0
 */
void mBT_WriteConfig(Int8 *aDataPtr);

/**
 * @brief Lecture d'un byte
 *
 * @param aBytePtr adresse dans laquelle stocker le byte (pas de vérification pour NULL)
 *
 * @return false si un charactère est lu, true sinon
 *
 * @since 1.0
 * @version 1.1
 */
bool mBT_ReadDataFromBuffer(Int8 *aBytePtr);

/**
 * @brief Lecture d'une chaine de caractères ( !FONCTION BLOQUANTE! )
 *
 * @brief buffer chaine de caractères dans laquelle écrire, pas de test pour NULL
 * @brief n nombre de caractères à lire
 *
 * @since 1.0
 * @version 1.0
 */
void mBT_readString(Int8 *buffer, UInt32 n);


#endif
